//! Example of running the test_git.rhai script
//!
//! This example demonstrates how to run the test_git.rhai script
//! through the Rhai scripting engine.

use sal::rhai::{self, Engine};
use std::fs;
use std::error::Error;

fn main() -> Result<(), Box<dyn Error>> {
    // Create a new Rhai engine
    let mut engine = Engine::new();
    
    // Register SAL functions with the engine
    rhai::register(&mut engine)?;
    
    // Read the test script
    let script = fs::read_to_string("src/test_git.rhai")?;
    
    // Evaluate the script
    match engine.eval::<()>(&script) {
        Ok(_) => println!("Script executed successfully"),
        Err(e) => eprintln!("Script execution error: {}", e),
    }
    
    Ok(())
}